Module: Line::Message::Builder::Flex::Position::Vertical
Overview
Provides the gravity option for vertical alignment of a component
within its parent Box (if the parent box's layout is horizontal
or baseline). For components like Image or Text, this controls
their vertical alignment within the space allocated to them.
Class Method Summary collapse
-
.included(base) ⇒ Object
:nodoc:.
Class Method Details
.included(base) ⇒ Object
:nodoc:
67 68 69 70 71 72 73 |
# File 'lib/line/message/builder/flex/position.rb', line 67 def self.included(base) base.option :gravity, # NOTE: API key is `gravity` (lowercase `g`) default: nil, validator: Validators::Enum.new( :top, :center, :bottom ) end |