Exception: Line::Message::Builder::RequiredError

Inherits:
Error
  • Object
show all
Defined in:
lib/line/message/builder.rb

Overview

Error raised when a required attribute or element is missing during message construction. For example, if a text message is created without specifying the text content.