Module: Line::Message::Builder::Flex::Position::Horizontal
Overview
Provides the align option for horizontal alignment of a component
within its parent Box (if the parent box's layout is vertical).
For components like Image or Text, this controls their horizontal
alignment within the space allocated to them.
Class Method Summary collapse
-
.included(base) ⇒ Object
:nodoc:.
Class Method Details
.included(base) ⇒ Object
:nodoc:
40 41 42 43 44 45 46 |
# File 'lib/line/message/builder/flex/position.rb', line 40 def self.included(base) base.option :align, default: nil, validator: Validators::Enum.new( :start, :center, :end ) end |