Module: Line::Message::Builder::Flex::Size::Flex
Overview
Provides the flex option, which determines the ratio of space a
component occupies within its parent Box relative to its siblings.
A higher flex value means the component will take up more space.
A value of 0 means the component does not flex (its size is fixed).
Class Method Summary collapse
-
.included(base) ⇒ Object
:nodoc:.
Class Method Details
.included(base) ⇒ Object
:nodoc:
39 40 41 42 |
# File 'lib/line/message/builder/flex/size.rb', line 39 def self.included(base) base.option :flex, default: nil # Default is 0 if not specified and parent is a Box end |